@@ -20,11 +20,11 @@ NULL
 ##'
 ##' \describe{
 ##'   \item{bestResult}{a S4 [\code{\linkS4class{MixmodDAResults}}] object containing the best model results.}
-##'   \item{nbCVBlocks}{integer which defines the number of observation per block to perform the Cross Validation.}
+##'   \item{nbCVBlocks}{integer which defines the number of block to perform the Cross Validation.}
 ##' }
 ##' @examples
 ##'   ## A quantitative example with the famous iris data set
-##'   new("MixmodLearn", data=iris[1:4], knownPartition=iris$Species)
+##'   new("MixmodLearn", data=iris[1:4], knownLabels=iris$Species)
 ##'
 ##'   getSlots("MixmodLearn")
 ##'
@@ -44,13 +44,13 @@ setClass(
   ),    
   # define validity function
   validity=function(object){  
-    # check whether the knownPartition is missing
-    if ( length(object@knownPartition) == 0 ){
-      stop("partition is missing!")
+    # check whether the knownLabels is missing
+    if ( length(object@knownLabels) == 0 ){
+      stop("labels are missing!")
     }
     # check the number of cluster
-    if ( (min(object@knownPartition)<=0) ){
-      stop("Each observation in knownPartition must have a valid cluster affectation !")
+    if ( (min(object@knownLabels)<=0) ){
+      stop("Each observation in knownLabels must have a valid cluster affectation !")
     }
     # check criterion parameter
     if ( sum(object@criterion %in% c("BIC","CV")) != length(object@criterion) ){
@@ -95,8 +95,8 @@ setMethod(
           .Object@bestResult@parameters = new("MultinomialParameter")
         }
         # create nbCluster
-        if(length(.Object@knownPartition)){
-          .Object@nbCluster <- max(.Object@knownPartition)
+        if(length(.Object@knownLabels)){
+          .Object@nbCluster <- max(.Object@knownLabels)
         }
         if(missing(criterion)){
             .Object@criterion <- "CV"
@@ -120,12 +120,11 @@ setMethod(
 ##' This function computes the first step of a discriminant analysis. It will find the best classification rule by running an M step from the training observations.
 ##' 
 ##' @param data matrix or data frame containing quantitative or qualitative data. Rows correspond to observations and columns correspond to variables.
-##' @param knownPartition vector of size number of observations. Each cell corresponds to a cluster affectation. So the maximum value is the number of clusters.
+##' @param knownLabels vector of size number of observations. Each cell corresponds to a cluster affectation. So the maximum value is the number of clusters.
 ##' @param dataType character. Type of data is either "quantitative" or "qualitative". Set as NULL by default, type will be guessed depending on variables type.
-##' @param factor vector of integer containing the number of modalities for each qualitative variable. It is optional for qualitative data set and keep it as NULL for quantitative data set. Factors can also be generated by the nbFactorFromData() method.
 ##' @param models a [\code{\linkS4class{Model}}] object defining the list of models to run. For quantitative data, the model "Gaussian_pk_Lk_C" is called (see mixmodGaussianModel() to specify other models). For qualitative data, the model "Binary_pk_Ekjh" is called (see mixmodMultinomialModel() to specify other models).
 ##' @param criterion list of character defining the criterion to select the best model. Possible values: "BIC", "CV" or c("CV","BIC"). Default is "CV".
-##' @param nbCVBlocks integer which defines the number of observation per block to perform the Cross Validation. This value will be ignored if the CV criterion is not choosen. Default value is 10.
+##' @param nbCVBlocks integer which defines the number of block to perform the Cross Validation. This value will be ignored if the CV criterion is not choosen. Default value is 10.
 ##' @param weight numeric vector with n (number of individuals) rows. Weight is optionnal. This option is to be used when weight is associated to the data.
 ##'
 ##' @examples
@@ -137,7 +136,7 @@ setMethod(
 ##'   ## An example with the famous birds data set
 ##'   data(birds)
 ##'   birds.partition<-c(rep(1,34),rep(2,35))
-##'   learn.birds<-mixmodLearn(data=birds, knownPartition=birds.partition, factor=c(2,5,6,3,5,4))
+##'   learn.birds<-mixmodLearn(data=birds, knownLabels=birds.partition)
 ##'   ## get summary
 ##'   summary(learn.birds)
 ##'
@@ -150,16 +149,16 @@ setMethod(
 
 ##' @export
 ##'
-mixmodLearn <- function(data, knownPartition, dataType=NULL, factor=NULL, models=NULL, criterion="CV", nbCVBlocks=10, weight=NULL) {
+mixmodLearn <- function(data, knownLabels, dataType=NULL, models=NULL, criterion="CV", nbCVBlocks=10, weight=NULL) {
   # check options
   if(missing(data)){
     stop("data is missing !")
   } 
-  if ( missing(knownPartition) ){
-    stop("knownPartition is missing !")
+  if ( missing(knownLabels) ){
+    stop("knownLabels is missing !")
   }
   # create Mixmod object
-  xem <- new( "MixmodLearn", data=data, knownPartition=knownPartition, dataType=dataType, factor=factor, models=models, criterion=criterion, nbCVBlocks=nbCVBlocks, weight=weight )
+  xem <- new( "MixmodLearn", data=data, knownLabels=knownLabels, dataType=dataType, models=models, criterion=criterion, nbCVBlocks=nbCVBlocks, weight=weight )
   # call learnMain
   .Call("learnMain", xem, PACKAGE="Rmixmod")
   # mixmod error?
@@ -187,6 +186,7 @@ setMethod(
       cat("\n\n")
       cat("****************************************\n")
       cat("*** BEST MODEL OUTPUT:\n")
+      cat(paste("*** According to the",x@criterion[1],"criterion\n")) 
       cat("****************************************\n")
       print(x@bestResult)
     }
@@ -217,6 +217,7 @@ setMethod(
       cat("\n\n")
       cat("****************************************\n")
       cat("*** BEST MODEL OUTPUT:\n")
+      cat(paste("*** According to the",object@criterion[1],"criterion\n")) 
       cat("****************************************\n")
       show(object@bestResult)
     }
@@ -248,7 +249,7 @@ setMethod(
         "nbCluster"={return(x@nbCluster)},
         "criterion"={return(x@criterion)},
         "models"={return(x@models)},
-        "knownPartition"={return(x@knownPartition)},
+        "knownLabels"={return(x@knownLabels)},
         "weight"={return(x@weight)},
         "bestResult"={return(x@bestResult)},
         "results"={return(x@results)},
@@ -260,7 +261,7 @@ setMethod(
         "nbCluster"={return(x@nbCluster[j])},
         "criterion"={return(x@criterion[j])},
         "data"={return(x@data[,j])},
-        "knownPartition"={return(x@knownPartition[,j])},
+        "knownLabels"={return(x@knownLabels[,j])},
         "weight"={return(x@weight[j])},
         "results"={return(x@results[[j]])},
         stop("This attribute doesn't exist !")
@@ -286,7 +287,7 @@ setReplaceMethod(
         "dataType"={x@dataType<-value},
         "criterion"={x@criterion<-value},
         "models"={x@models<-value},
-        "knownPartition"={x@knownPartition<-value},
+        "knownLabels"={x@knownLabels<-value},
         "weight"={x@weight<-value},
         stop("This attribute doesn't exist !")
       )
@@ -294,7 +295,7 @@ setReplaceMethod(
       switch(EXPR=i,
         "data"={x@data[,j]<-value},
         "criterion"={x@criterion[j]<-value},
-        "knownPartition"={x@knownPartition[j]<-value},
+        "knownLabels"={x@knownLabels[j]<-value},
         "weight"={x@weight[j]<-value},
         stop("This attribute doesn't exist !")
       )
